@@ -1,19 +1,14 @@
 """Code from https://github.com/LeonardoBringel/HammingCode
-
 MIT License
-
 Copyright (c) 2022 Leonardo Bringel
-
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:
-
 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.
-
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -28,7 +23,7 @@ def parity_index(bits):
     bit_index = 2
     parity_location = [0]
 
-    while bit_index < len(bits):
+    while bit_index < len(bits)//8 * 8:
         parity_location.append(bit_index - 1)
         bit_index = bit_index * 2
     return parity_location
